import * as Rx from 'rxjs/Rx';
import { IterableLike } from '../util/IterableLike';
import { Trie } from 'cspell-trie';
export interface SuggestionResult {
    word: string;
    cost: number;
}
export interface SpellingDictionary {
    readonly name: string;
    has(word: string): boolean;
    suggest(word: string, numSuggestions?: number): SuggestionResult[];
    readonly size: number;
}
export declare class SpellingDictionaryFromSet implements SpellingDictionary {
    readonly words: Set<string>;
    readonly name: string;
    private _trie;
    constructor(words: Set<string>, name: string);
    readonly trie: Trie;
    has(word: string): boolean;
    suggest(word: string, numSuggestions?: number): SuggestionResult[];
    readonly size: number;
}
export declare function createSpellingDictionary(wordList: string[] | IterableLike<string>, name: string): SpellingDictionary;
export declare function createSpellingDictionaryRx(words: Rx.Observable<string>, name: string): Promise<SpellingDictionary>;
export declare class SpellingDictionaryFromTrie implements SpellingDictionary {
    readonly trie: Trie;
    readonly name: string;
    static readonly unknownWordsLimit: number;
    private _size;
    readonly knownWords: Set<string>;
    readonly unknownWords: Set<string>;
    constructor(trie: Trie, name: string);
    readonly size: number;
    has(word: string): boolean;
    suggest(word: string, numSuggestions?: number): SuggestionResult[];
}
export declare function createSpellingDictionaryTrie(data: Rx.Observable<string>, name: string): Promise<SpellingDictionary>;
